##################################
### NoTriggers.tcl             ###
### Version 2.2                ###
### By Wcc                     ###
### wcc@techmonkeys.org        ###
### http://www.dawgtcl.com:81/ ###
### EFnet #|DAWG|Tcl           ###
##################################

############################################################################
### Copyright  2000 - 2002 |DAWG| Scripting Group. All rights reserved. ###
############################################################################

##############################################################################
## This script warns users if they type a banned trigger in the channel. It ##
## kicks on the second offense and bans on the third.                       ##
##############################################################################

##############
## COMMANDS ##
##################################################################
## DCC ## .chanset <channel> +/-notriggers                      ##
######### Enables or disables trigger protection for a channel. ##
##################################################################

##########################################################
## Just load the script, edit the settings, and rehash. ##
##########################################################

###########################################################################
# Set the time in minutes before a ban expires here. If set to 0, the ban #
# will not be removed.                                                    #
###########################################################################

set notriggers_setting(exp) "0"

###################################################################
# Set the list of invalid triggers here. Wildcards are supported. #
###################################################################

set notriggers_setting(triggers) {
	"!list"
	"@find *"
	"@locator *"
	"!seen *"
}

###############################################################################
# Set the warning message sent to the channel here. %nick is substituted with #
# the offending user's nick. %chan is the current channel. %trigger is the    #
# first 'word' of the trigger the user typed.                                 #
###############################################################################

set notriggers_setting(msg) "%nick, please do not use the %trigger tigger in %chan."

##############################################################################
# Set the first kick message text here. %nick is substituted with the        #
# offending user's nick. %chan is the current channel. %trigger is the first #
# 'word' of the trigger the user typed.                                      #
##############################################################################

set notriggers_setting(kmsg) "Please do not use the %trigger tigger in %chan. The next time you use this trigger, you will be banned."

##############################################################################
# Set the second kick message text here. %nick is substituted with the       #
# offending user's nick. %chan is the current channel. %trigger is the first #
# 'word' of the trigger the user typed.                                      #
##############################################################################

set notriggers_setting(kmsg2) "Please do not use the %trigger tigger in %chan."

#############################
# Set the ban type here:    #
# 1 - *!*@host.domain	    #
# 2 - *!user@host.domain    #
# 3 - nick!*@host.domain    #
# 4 - nick!user@host.domain #
# 5 - *!?user@*.host.domain #
#############################

set notriggers_setting(bantype) "1"

####################
# Code begins here #
####################

if {![string match 1.6.* $version]} { putlog "\002NOTRIGGERS:\002 \002WARNING:\002 This script is intended to run on eggdrop 1.6.x or later." }
if {[info tclversion] < 8.2} { putlog "\002NOTRIGGERS:\002 \002WARNING:\002 This script is intended to run on Tcl Version 8.2 or later." }

setudef flag notriggers

bind raw - PRIVMSG notriggers_parse

proc notriggers_maskban {nick uhost} {
	switch -regexp -- $::notriggers_setting(bantype) {
		"1|3" { set ban "[expr {($::notriggers_setting(bantype) == 1) ? "*" : "$nick"}]!*@[lindex [split $uhost @] 1]" }
		"2|4|5" { set ban "[expr {($::notriggers_setting(bantype) == 2) ? "*" : "$nick"}]!$uhost" }
		"5" { set ban "[maskhost $uhost]" }
		default { set ban "*!*@[lindex [split $uhost @] 1]" }
	}
	return $ban
}
proc notriggers_parse {from key text} {
	foreach {s v} [list chan [join [lrange [split $text] 0 0]] text [string trimleft [join [lrange [split $text] 1 end]] :] nick [join [lrange [split $from !] 0 0]] uhost [join [lrange [split $from !] 1 1]]] { set $s $v }
	set hand [expr {([regexp {^\\*$|^$} [nick2hand $nick]]) ? "" : "[nick2hand $nick]"}]
	if {![botisop $chan] || [isop $nick $chan] || [lsearch -exact [channel info $chan] +notriggers] == -1} { return }
	foreach {s v} [list found 0 banmask [notriggers_maskban $nick $uhost]] { set $s $v }
	foreach t [string tolower $::notriggers_setting(triggers)] {
		if {![string match $t [string tolower $text]]} { continue }
		foreach {s v} [list trigger $t found 1] { set $s $v }
		break
	}
	if {!$found} { return }
	if {![info exists ::notriggers_trigarray([set name [string tolower $chan]![lindex [split $text] 0]![lindex [split $uhost @] 1]])]} { set ::notriggers_trigarray($name) 0 }
	incr ::notriggers_trigarray($name)
	switch -regexp -- $::notriggers_trigarray($name) {
		"1|2" {
			set msg $::notriggers_setting([expr {($::notriggers_trigarray($name) == 1) ? "msg" : "kmsg"}])
			foreach {a b} [list %nick $nick %trigger [lindex [split $trigger] 0] %chan $chan] { regsub -all -- $a $msg $b msg }
			putserv "[expr {($::notriggers_trigarray($name) == 1) ? "PRIVMSG $chan " : "KICK $chan $nick "}]:$msg"
		}
		default {
			set msg $::notriggers_setting(kmsg2)
			foreach {a b} [list %nick $nick %trigger [lindex [split $trigger] 0] %chan $chan] { regsub -all -- $a $msg $b msg }
			putserv "MODE $chan +b $banmask"
			putserv "KICK $chan $nick :$msg"
			if {$notriggers_setting(exp) > 0} { timer $notriggers_setting(exp) [list putserv "MODE $chan -b $banmask"] }
		}
	}
}
putlog "\002NOTRIGGERS:\002 NoTriggers.tcl Version 2.2 by Wcc is loaded."
